//
//  ShaderBezier.fsh
//  Game Engine
//

#extension GL_OES_standard_derivatives : enable

varying lowp vec4 vv4Color;
varying lowp vec2 vv2UV;

uniform sampler2D tex;

void main()
{
    gl_FragColor = vv4Color;
    
    lowp vec2 vv2UVabs = vec2(vv2UV.x, abs(vv2UV.y));
    
    // gradients
    lowp vec2 duvdx = dFdx(vv2UVabs);
    lowp vec2 duvdy = dFdy(vv2UVabs);
    
    // chain rule (u,v) -> (x,y)
    lowp float tx = (-2.0*vv2UV.x + 1.0)*duvdx.x - duvdx.y;
    lowp float ty = (-2.0*vv2UV.x + 1.0)*duvdy.x - duvdy.y;
    
    lowp float sd = ((vv2UV.x - vv2UV.x * vv2UV.x) * sign(vv2UV.y) - vv2UV.y) / sqrt(tx*tx + ty*ty);
    lowp float alpha = sd + 0.5;
    
    if (alpha > 1.0)
        gl_FragColor.a = 1.0;
    else if (alpha < 0.0)
        gl_FragColor.a = 0.0;
    else
        gl_FragColor.a = alpha;

    
//    if ( (vv2UV.x - vv2UV.x * vv2UV.x) * sign(vv2UV.y) - vv2UV.y < 0.0 )
//        gl_FragColor.a = 0.0;
    
//    if ( (-vv2UV.x*vv2UV.x + vv2UV.x - abs(vv2UV.y)) * sign(vv2UV.y) < 0.0 )
//        gl_FragColor.a = 0.0;
}